@@ -1,8 +1,7 @@
 package dynamodb
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -75,28 +74,23 @@ resource "aws_dynamodb_table" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("point_in_time_recovery") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' doesn't have point in time recovery", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' doesn't have point in time recovery", resourceBlock.FullName())
 				return
 			}
 
-			poitBlock := resourceBlock.GetBlock("point_in_time_recovery")
-			if poitBlock.MissingChild("enabled") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' doesn't have point in time recovery enabled", resourceBlock.FullName())),
-				)
+			pointBlock := resourceBlock.GetBlock("point_in_time_recovery")
+			if pointBlock.MissingChild("enabled") {
+				set.AddResult().
+					WithDescription("Resource '%s' doesn't have point in time recovery enabled", resourceBlock.FullName()).
+					WithBlock(pointBlock)
 				return
 			}
-			enabledAttr := poitBlock.GetAttribute("enabled")
+			enabledAttr := pointBlock.GetAttribute("enabled")
 			if enabledAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' doesn't have point in time recovery enabled", resourceBlock.FullName())).
-						WithAttribute(enabledAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' doesn't have point in time recovery enabled", resourceBlock.FullName()).
+					WithAttribute(enabledAttr)
 			}
 
 		},
