@@ -1,5 +1,6 @@
 package elasticsearch
 
+// generator-locked
 import (
 	"testing"
 
@@ -44,6 +45,18 @@ resource "aws_elasticsearch_domain" "my_elasticsearch_domain" {
   node_to_node_encryption {
     enabled = true
   }
+}`,
+			mustExcludeResultCode: expectedCode,
+		},
+		{
+			name: "check true enabled attr aws_elasticsearch_domain",
+			source: `
+resource "aws_elasticsearch_domain" "my_elasticsearch_domain" {
+  domain_name = "domain-foo"
+
+  node_to_node_encryption {
+    enabled = "true"
+  }
 }`,
 			mustExcludeResultCode: expectedCode,
 		},
