@@ -1,8 +1,7 @@
 package rds
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -95,20 +94,16 @@ resource "aws_rds_cluster" "good_example" {
 			}
 
 			if resourceBlock.MissingChild("backup_retention_period") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not have backup retention explicitly set", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not have backup retention explicitly set", resourceBlock.FullName())
 				return
 			}
 
 			retentionAttr := resourceBlock.GetAttribute("backup_retention_period")
 			if retentionAttr.LessThanOrEqualTo(1) {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has backup retention period set to a low value", resourceBlock.FullName())).
-						WithAttribute(retentionAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has backup retention period set to a low value", resourceBlock.FullName()).
+					WithAttribute(retentionAttr)
 			}
 
 		},
