@@ -1,8 +1,7 @@
 package rds
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -56,24 +55,15 @@ resource "aws_rds_cluster" "good_example" {
 			kmsKeyIdAttr := resourceBlock.GetAttribute("kms_key_id")
 			storageEncryptedattr := resourceBlock.GetAttribute("storage_encrypted")
 
-			if (kmsKeyIdAttr == nil || kmsKeyIdAttr.IsEmpty()) &&
-				(storageEncryptedattr == nil || storageEncryptedattr.IsFalse()) {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines a disabled RDS Cluster encryption.", resourceBlock.FullName())),
-				)
-			} else if kmsKeyIdAttr != nil && kmsKeyIdAttr.Equals("") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines a disabled RDS Cluster encryption.", resourceBlock.FullName())).
-						WithAttribute(kmsKeyIdAttr),
-				)
-			} else if storageEncryptedattr == nil || storageEncryptedattr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines a enabled RDS Cluster encryption but not the required encrypted_storage.", resourceBlock.FullName())).
-						WithAttribute(kmsKeyIdAttr),
-				)
+			if kmsKeyIdAttr.IsEmpty() && storageEncryptedattr.IsFalse() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines a disabled RDS Cluster encryption.", resourceBlock.FullName())
+			} else if kmsKeyIdAttr.IsNotNil() && kmsKeyIdAttr.Equals("") {
+				set.AddResult().
+					WithDescription("Resource '%s' defines a disabled RDS Cluster encryption.", resourceBlock.FullName())
+			} else if storageEncryptedattr.IsNil() || storageEncryptedattr.IsFalse() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines a enabled RDS Cluster encryption but not the required encrypted_storage.", resourceBlock.FullName())
 			}
 		},
 	})
