@@ -20,26 +20,44 @@ func Test_AWSS3BucketShouldHavePublicAccessBlock(t *testing.T) {
 			name: "Should fail when a bucket is missing the public access block",
 			source: `
 resource "aws_s3_bucket" "example" {
-  bucket = "example"
-  acl = "private-read"
+	bucket = "example"
+	acl = "private-read"
+}
+		`,
+			mustIncludeResultCode: expectedCode,
+		},
+		{
+			name: "Should fail when a bucket is missing the public access block (via foreach)",
+			source: `
+resource "aws_s3_bucket" "example" {
+	for_each      = toset(["example1", "example2"])
+	bucket        = each.key
+}
+	
+resource "aws_s3_bucket_public_access_block" "example" {
+	for_each = aws_s3_bucket.example
+	bucket   = each.value.id
+	
+	block_public_acls       = true
+	block_public_policy     = true
 }
 `,
-			mustIncludeResultCode: expectedCode,
+			mustExcludeResultCode: expectedCode,
 		},
 		{
 			name: "Should pass when a bucket is not missing the public access block",
 			source: `
 resource "aws_s3_bucket" "example" {
-  bucket = "example"
-  acl = "private-read"
+	bucket = "example"
+	acl = "private-read"
 }
-  
+
 resource "aws_s3_bucket_public_access_block" "example" {
-  bucket = aws_s3_bucket.example.id
-  block_public_acls   = true
-  block_public_policy = true
+	bucket = aws_s3_bucket.example.id
+	block_public_acls   = true
+	block_public_policy = true
 }
-`,
+		`,
 			mustExcludeResultCode: expectedCode,
 		},
 	}
