@@ -1,8 +1,7 @@
 package sns
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -53,18 +52,14 @@ resource "aws_sns_topic" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, ctx *hclcontext.Context) {
 
 			kmsKeyIDAttr := resourceBlock.GetAttribute("kms_master_key_id")
-			if kmsKeyIDAttr == nil {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an unencrypted SNS topic.", resourceBlock.FullName())),
-				)
+			if kmsKeyIDAttr.IsNil() {
+				set.AddResult().
+					WithDescription("Resource '%s' defines an unencrypted SNS topic.", resourceBlock.FullName())
 				return
 			} else if kmsKeyIDAttr.Type() == cty.String && kmsKeyIDAttr.Value().AsString() == "" {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' defines an unencrypted SNS topic.", resourceBlock.FullName())).
-						WithAttribute(kmsKeyIDAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' defines an unencrypted SNS topic.", resourceBlock.FullName()).
+					WithAttribute(kmsKeyIDAttr)
 				return
 			}
 
@@ -76,12 +71,10 @@ resource "aws_sns_topic" "good_example" {
 				}
 
 				keyIdAttr := kmsData.GetAttribute("key_id")
-				if keyIdAttr != nil && keyIdAttr.Equals("alias/aws/sns") {
-					set.Add(
-						result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Resource '%s' explicitly uses the default CMK", resourceBlock.FullName())).
-							WithAttribute(kmsKeyIDAttr),
-					)
+				if keyIdAttr.IsNotNil() && keyIdAttr.Equals("alias/aws/sns") {
+					set.AddResult().
+						WithDescription("Resource '%s' explicitly uses the default CMK", resourceBlock.FullName()).
+						WithAttribute(kmsKeyIDAttr)
 				}
 
 			}
