@@ -1,8 +1,7 @@
 package vpc
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -15,8 +14,6 @@ import (
 	"github.com/aquasecurity/tfsec/pkg/rule"
 
 	"github.com/aquasecurity/tfsec/internal/app/tfsec/scanner"
-
-	"github.com/zclconf/go-cty/cty"
 )
 
 var outdatedSSLPolicies = []string{
@@ -60,14 +57,12 @@ resource "aws_alb_listener" "good_example" {
 		DefaultSeverity: severity.Critical,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
-			if sslPolicyAttr := resourceBlock.GetAttribute("ssl_policy"); sslPolicyAttr != nil && sslPolicyAttr.Type() == cty.String {
+			if sslPolicyAttr := resourceBlock.GetAttribute("ssl_policy"); sslPolicyAttr.IsString() {
 				for _, policy := range outdatedSSLPolicies {
-					if policy == sslPolicyAttr.Value().AsString() {
-						set.Add(
-							result.New(resourceBlock).
-								WithDescription(fmt.Sprintf("Resource '%s' is using an outdated SSL policy.", resourceBlock.FullName())).
-								WithAttribute(sslPolicyAttr),
-						)
+					if sslPolicyAttr.Equals(policy) {
+						set.AddResult().
+							WithDescription("Resource '%s' is using an outdated SSL policy.", resourceBlock.FullName()).
+							WithAttribute(sslPolicyAttr)
 					}
 				}
 			}
