@@ -1,8 +1,7 @@
 package database
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -57,20 +56,16 @@ resource "azurerm_postgresql_server" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("ssl_enforcement_enabled") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' is missing the required ssl_enforcement_enabled attribute", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' is missing the required ssl_enforcement_enabled attribute", resourceBlock.FullName())
 				return
 			}
 
 			sslEnforceAttr := resourceBlock.GetAttribute("ssl_enforcement_enabled")
 			if sslEnforceAttr.IsFalse() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' has ssl_enforcement_enabled disabled", resourceBlock.FullName())).
-						WithAttribute(sslEnforceAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' has ssl_enforcement_enabled disabled", resourceBlock.FullName()).
+					WithAttribute(sslEnforceAttr)
 			}
 		},
 	})
