@@ -1,8 +1,7 @@
 package database
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -80,10 +79,8 @@ resource "azurerm_mssql_database_extended_auditing_policy" "good_example" {
 				return
 			}
 			if resourceBlock.GetAttribute("retention_in_days").LessThan(90) {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' specifies a retention period of less than 90 days.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' specifies a retention period of less than 90 days.", resourceBlock.FullName())
 			}
 
 		},
