@@ -1,8 +1,7 @@
 package datafactory
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -58,17 +57,14 @@ resource "azurerm_data_factory" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("public_network_enabled") {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' should have public_network_enabled set to false, the default is true.", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' should have public_network_enabled set to false, the default is true.", resourceBlock.FullName())
 				return
 			}
-			if resourceBlock.GetAttribute("public_network_enabled").IsTrue() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' should not have public network set to true.", resourceBlock.FullName())),
-				)
+			publicAccessAttr := resourceBlock.GetAttribute("public_network_enabled")
+			if publicAccessAttr.IsTrue() {
+				set.AddResult().
+					WithDescription("Resource '%s' should not have public network set to true.", resourceBlock.FullName())
 			}
 		},
 	})
