@@ -1,8 +1,7 @@
 package securitycenter
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -57,19 +56,17 @@ resource "azurerm_security_center_contact" "good_example" {
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
 			if resourceBlock.MissingChild("phone") {
-				set.Add(
-					result.New(resourceBlock).WithDescription(fmt.Sprintf("Resource '%s' does not have a phone number set for the security contact", resourceBlock.FullName())),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not have a phone number set for the security contact", resourceBlock.FullName())
+
 				return
 			}
 
 			phoneAttr := resourceBlock.GetAttribute("phone")
 			if phoneAttr.IsEmpty() {
-				set.Add(
-					result.New(resourceBlock).
-						WithDescription(fmt.Sprintf("Resource '%s' does not have a phone number set for the security contact", resourceBlock.FullName())).
-						WithAttribute(phoneAttr),
-				)
+				set.AddResult().
+					WithDescription("Resource '%s' does not have a phone number set for the security contact", resourceBlock.FullName()).
+					WithAttribute(phoneAttr)
 			}
 		},
 	})
