@@ -1,8 +1,7 @@
 package secrets
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 	"github.com/zclconf/go-cty/cty"
@@ -95,10 +94,8 @@ resource "evil_corp" "good_example" {
 				}
 				if security.IsSensitiveAttribute(attribute.Name()) {
 					if attribute.IsResolvable() && attribute.Type() == cty.String && !attribute.Equals("") {
-						set.Add(result.New(resourceBlock).
-							WithDescription(fmt.Sprintf("Block '%s' includes a potentially sensitive attribute which is defined within the project.", resourceBlock.FullName())).
-							WithAttribute(attribute),
-						)
+						set.AddResult().WithDescription("Block '%s' includes a potentially sensitive attribute which is defined within the project.", resourceBlock.FullName()).
+							WithAttribute(attribute)
 					}
 
 				}
