@@ -1,8 +1,7 @@
 package sql
 
+// generator-locked
 import (
-	"fmt"
-
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
 
@@ -61,30 +60,23 @@ resource "google_sql_database_instance" "db" {
 		RequiredLabels:  []string{"google_sql_database_instance"},
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
-			// we only need to check this for SQLSERVER, not mysql/postgres
-			dbVersionAttr := resourceBlock.GetAttribute("database_version")
-			if dbVersionAttr == nil || !dbVersionAttr.IsString() {
-				// default is postgres
-				return
-			}
 
-			if !dbVersionAttr.StartsWith("MYSQL") {
+			// we only need to check this for MYSQL
+			if !resourceBlock.GetAttribute("database_version").StartsWith("MYSQL") {
 				return
 			}
 
 			settingsBlock := resourceBlock.GetBlock("settings")
-			if settingsBlock == nil {
+			if settingsBlock.IsNil() {
 				return
 			}
 
 			for _, dbFlagBlock := range settingsBlock.GetBlocks("database_flags") {
-				if nameAttr := dbFlagBlock.GetAttribute("name"); nameAttr != nil && nameAttr.IsString() && nameAttr.Equals("local_infile") {
-					if valueAttr := dbFlagBlock.GetAttribute("value"); valueAttr != nil && valueAttr.IsString() {
+				if nameAttr := dbFlagBlock.GetAttribute("name"); nameAttr.IsNotNil() && nameAttr.IsString() && nameAttr.Equals("local_infile") {
+					if valueAttr := dbFlagBlock.GetAttribute("value"); valueAttr.IsNotNil() && valueAttr.IsString() {
 						if valueAttr.Equals("on", block.IgnoreCase) {
-							set.Add(
-								result.New(resourceBlock).
-									WithDescription(fmt.Sprintf("Resource '%s' has local file read access enabled.", resourceBlock.FullName())),
-							)
+							set.AddResult().
+								WithDescription("Resource '%s' has local file read access enabled.", resourceBlock.FullName())
 						}
 					}
 				}
