@@ -1,5 +1,6 @@
 package storage
 
+// generator-locked
 import (
 	"github.com/aquasecurity/tfsec/pkg/result"
 	"github.com/aquasecurity/tfsec/pkg/severity"
@@ -53,22 +54,18 @@ resource "google_storage_bucket_iam_binding" "binding" {
 		DefaultSeverity: severity.High,
 		CheckFunc: func(set result.Set, resourceBlock block.Block, _ *hclcontext.Context) {
 
-			if memberAttr := resourceBlock.GetAttribute("member"); memberAttr != nil && memberAttr.IsString() {
+			if memberAttr := resourceBlock.GetAttribute("member"); memberAttr.IsString() {
 				if googleIAMMemberIsExternal(memberAttr.Value().AsString()) {
-					set.Add(result.New(resourceBlock).
-						WithDescription("Resource '%s' allows public access via member attribute.").
-						WithAttribute(memberAttr),
-					)
+					set.AddResult().WithDescription("Resource '%s' allows public access via member attribute.", resourceBlock.FullName()).
+						WithAttribute(memberAttr)
 				}
 			}
 
-			if membersAttr := resourceBlock.GetAttribute("members"); membersAttr != nil {
+			if membersAttr := resourceBlock.GetAttribute("members"); membersAttr.IsNotNil() {
 				for _, member := range membersAttr.ValueAsStrings() {
 					if googleIAMMemberIsExternal(member) {
-						set.Add(result.New(resourceBlock).
-							WithDescription("Resource '%s' allows public access via members attribute.").
-							WithAttribute(membersAttr),
-						)
+						set.AddResult().WithDescription("Resource '%s' allows public access via members attribute.", resourceBlock.FullName()).
+							WithAttribute(membersAttr)
 					}
 				}
 			}
