@@ -5,6 +5,7 @@ import (
 	"io/ioutil"
 	"os"
 	"path/filepath"
+	"strings"
 	"testing"
 
 	"github.com/aquasecurity/tfsec/pkg/result"
@@ -53,12 +54,16 @@ func CreateTestFile(filename, contents string) string {
 }
 
 func AssertCheckCode(t *testing.T, includeCode string, excludeCode string, results []result.Result, messages ...string) {
-
 	var foundInclude bool
 	var foundExclude bool
 
 	var excludeText string
 
+	if !validateCodes(includeCode, excludeCode) {
+		t.Logf("Either includeCode (%s) or excludeCode (%s) was invalid ", includeCode, excludeCode)
+		t.FailNow()
+	}
+
 	for _, res := range results {
 		if res.RuleID == excludeCode {
 			foundExclude = true
@@ -73,6 +78,10 @@ func AssertCheckCode(t *testing.T, includeCode string, excludeCode string, resul
 	if includeCode != "" {
 		assert.True(t, foundInclude, fmt.Sprintf("res with code '%s' was not found but should have been", includeCode))
 	}
+
+	if t.Failed() {
+		t.Log(strings.ReplaceAll(t.Name(), "_", " "))
+	}
 }
 
 func CreateTestFileWithModule(contents string, moduleContents string) string {
@@ -102,3 +111,18 @@ func CreateTestFileWithModule(contents string, moduleContents string) string {
 
 	return rootPath
 }
+
+func validateCodes(includeCode, excludeCode string) bool {
+	if includeCode != "" {
+		if _, err := scanner.GetRuleById(includeCode); err != nil {
+			return false
+		}
+	}
+
+	if excludeCode != "" {
+		if _, err := scanner.GetRuleById(excludeCode); err != nil {
+			return false
+		}
+	}
+	return true
+}
